==> kjy-center-api-0.5.99-ctc2-20191225.092141-2-sources.jar: cn/com/duiba/kjy/api/enums/MessageMarkEnum.java <==
package cn.com.duiba.kjy.api.enums;

import java.util.Objects;

/**
 * Created by dugq on 2019-06-29.
 * 消息配置的标记。一个功能一个标记。切勿重复哦
 */
public enum MessageMarkEnum {
    /**
     * 公众号、小程序消息配置
     */
    DAILY_TEMPLATE(1,"日报降级"),
    VISIT_TEMPLATE(2,"访问记录降级"),
    BUY_VIP_TEMPLATE(3,"会员购买成功"),
    SHARE_STATISTICS_TEMPLATE(4,"每日统计"),
    EVENING_GREETING_TEMPLATE(5,"晚安问候降级"),
    RETURN_MONEY(6,"收益发放通知"),
    WITHDRAW_MONEY(7,"提现成功通知"),

    VIP_INCOME_STATISTICS_TEMPLATE(8,"每日收益模板消息"),
    GUIDING_SUBSCRIBE_VIP(9,"引导关注VIP客服消息"),
    EVENING_GREETING_KEFU(10,"晚安问候客服消息"),
    USER_IN_CHAT_PAGE(11,"客户咨询客服消息通知，客户首次进入该会话聊天页"),
    USER_IN_CHAT_PAGE_TEMPLATE(12,"客户咨询模板消息通知，客户首次进入该会话聊天页"),
    USER_SEND_MESSAGE(13,"用户咨询客服消息通知，客户给代理人留言"),
    USER_SEND_MESSAGE_TEMPLATE(14,"用户咨询模板消息通知，客户给代理人留言"),
    USER_RECEIVE_MESSAGE(15,"客户接收代理人留言客服消息通知，客户消息小程序"),
    UPGRADE_GRADE_TEMPLATE(16,"等级升级通知"),
    ORDER_SEND_OUT(17,"订单发货通知"),

    AFTERNOON_ACTIVITY_KEFU(18,"下午动画推荐客服消息"),
    AFTERNOON_ACTIVITY_TEMPLATE(19,"午间动画推荐降级"),

    PRIVATE_CHAT_TEMPLATE(20,"代理人回复私聊，小程序模版消息"),

    SALES_PROMOTION_ONE_TEXT(21,"会销未付款用户22小时客服文字消息"),
    SALES_PROMOTION_TWO_TEXT(22,"会销未付款用户48小时客服文字消息"),
    SALES_PROMOTION_REMIND_PIC(23,"会销未付款用户48小时客服图文消息"),
    HOT_CONTENT_TEMPLATE(24, "热点内容模版消息"),
    COLLECT_CONTENT_INTERACTION(25, "收藏通知消息"),
    ACTIVITY_ACCURATE_CLUE(26, "活动精准线索推送"),
    ACCURATE_CLUE_TEMPLATE(27, "精准线索模版推送"),

    EVENING_GREETING_TEMPLATE_TEST(29,"晚安问候降级测试"),

    FISSION_SOMEONE_HELPED_ASSISTANCE(30, "裂变：有好友帮你助力"),
    FISSION_ASSISTANCE_HELP_OTHER(31, "裂变：帮好友助力"),
    FISSION_ASSISTANCE_SUCCESS(32, "裂变：助力完成，提醒领奖"),
    FISSION_AGENT_TAKE_ACTIVITY(33, "裂变：参与活动,通知代理人"),
    FISSION_TAKE_ACTIVITY(34, "裂变：参与活动"),
    FISSION_AGENT_COMPLETE_ACTIVITY(35, "裂变：有人完成,通知代理人"),
    FISSION_AGENT_MULTIPLE_MESSAGE(36, "裂变：代理人综合消息"),
    FISSION_USER_RECEIVE_MESSAGE(37, "裂变：用户收到代理人的私聊消息"),
    FISSION_SELLER_RECEIVE_MESSAGE(43, "裂变：代理人收到用户的私聊消息"),

    SINGLE_MESSAGE_USE(38, "自定义推送1"),
    EARLY_WARNING_REMIND_TEMPLATE(39,"预警提醒"),

    CUSTOM_MESSAGE_SEND(40,"自定义内容推送模版降级"),
    AFTERNOON_CONTENT_PUSH(41,"12点内容推送"),

    DAILY_TEMPLATE_TEST(42,"日报降级测试"),
    AFTERNOON_ACTIVITY_TEMPLATE_TEST(44,"午间动画推荐降级测试"),

    TEST_REPORT_TEMPLATE(45,"测算报告通知"),


    GAME_TEMPLATE_LOTTERY(50, "抽奖工具：参与抽奖聚合推送"),
    GAME_TEMPLATE_LOTTERY_CUSTOM(51, "抽奖工具：中销售员指定奖品"),
    GAME_TEMPLATE_RECEIVED_CUSTOM(52, "抽奖工具：领取销售员指定奖品"),
    GAME_TEMPLATE_RECEIVED_CUSTOM_TEMPLATE(53, "抽奖工具：领取销售员指定奖品降级模板"),
    EVENING_GREETING_CUSTOM_TEXT(54, "晚安心语客服文字消息"),

    TODAY_LUCK_CUSTOM_TEXT(55, "今日运势推送"),

    /**
     * 自定义推送模版占用 60-70.具体模版名称在备注中。根据实际情况选择性，动态配置
     */
    CUSTOM_PUSH_TEMPLATE_2(60, "自定义推送2"),
    CUSTOM_PUSH_TEMPLATE_3(61, "自定义推送3"),
    CUSTOM_PUSH_TEMPLATE_4(62, "自定义推送4"),
    CUSTOM_PUSH_TEMPLATE_5(63, "自定义推送5"),
    CUSTOM_PUSH_TEMPLATE_10(70, "自定义推送10"),

    NEW_YEAR_ACTIVITY_PUSH_TEMPLATE(71, "元旦活动降级模版"),

    GREETING_CARD_RECEIVE(75, "节日贺卡：访客收下了贺卡"),
    GREETING_CARD_RECEIVE_DEMOTION(76, "节日贺卡：访客收下了贺卡降级模板"),
    GREETING_CARD_THANKS(77, "节日贺卡：访客答谢了贺卡"),
    GREETING_CARD_THANKS_DEMOTION(78, "节日贺卡：访客答谢了贺卡降级模板"),


    ;
    private Integer mark;
    private String desc;

    MessageMarkEnum(Integer mark, String desc) {
        this.mark = mark;
        this.desc = desc;
    }

    public Integer getMark() {
        return mark;
    }

    public String getDesc() {
        return desc;
    }

    public static MessageMarkEnum Of(Integer type) {
        for (MessageMarkEnum e :values())
            if (Objects.equals(type, e.getMark())) {
                return e;
            }
        throw new UnsupportedOperationException("不支持的消息");
    }

}

==> kjy-center-api-0.7.50-ctc12-20200211.054401-3-sources.jar: cn/com/duiba/kjy/api/enums/MessageMarkEnum.java <==
package cn.com.duiba.kjy.api.enums;

import java.util.Objects;

/**
 * Created by dugq on 2019-06-29.
 * 消息配置的标记。一个功能一个标记。切勿重复哦
 */
public enum MessageMarkEnum {
    /**
     * 公众号、小程序消息配置
     */
    DAILY_TEMPLATE(1,"日报降级"),
    VISIT_TEMPLATE(2,"访问记录降级"),
    BUY_VIP_TEMPLATE(3,"会员购买成功"),
    SHARE_STATISTICS_TEMPLATE(4,"每日统计"),
    EVENING_GREETING_TEMPLATE(5,"晚安问候降级"),
    RETURN_MONEY(6,"收益发放通知"),
    WITHDRAW_MONEY(7,"提现成功通知"),

    VIP_INCOME_STATISTICS_TEMPLATE(8,"每日收益模板消息"),
    GUIDING_SUBSCRIBE_VIP(9,"引导关注VIP客服消息"),
    EVENING_GREETING_KEFU(10,"晚安问候客服消息"),
    USER_IN_CHAT_PAGE(11,"客户咨询客服消息通知，客户首次进入该会话聊天页"),
    USER_IN_CHAT_PAGE_TEMPLATE(12,"客户咨询模板消息通知，客户首次进入该会话聊天页"),
    USER_SEND_MESSAGE(13,"用户咨询客服消息通知，客户给代理人留言"),
    USER_SEND_MESSAGE_TEMPLATE(14,"用户咨询模板消息通知，客户给代理人留言"),
    USER_RECEIVE_MESSAGE(15,"客户接收代理人留言客服消息通知，客户消息小程序"),
    UPGRADE_GRADE_TEMPLATE(16,"等级升级通知"),
    ORDER_SEND_OUT(17,"订单发货通知"),

    AFTERNOON_ACTIVITY_KEFU(18,"下午动画推荐客服消息"),
    AFTERNOON_ACTIVITY_TEMPLATE(19,"午间动画推荐降级"),

    PRIVATE_CHAT_TEMPLATE(20,"代理人回复私聊，小程序模版消息"),

    SALES_PROMOTION_ONE_TEXT(21,"会销未付款用户22小时客服文字消息"),
    SALES_PROMOTION_TWO_TEXT(22,"会销未付款用户48小时客服文字消息"),
    SALES_PROMOTION_REMIND_PIC(23,"会销未付款用户48小时客服图文消息"),
    HOT_CONTENT_TEMPLATE(24, "热点内容模版消息"),
    COLLECT_CONTENT_INTERACTION(25, "收藏通知消息"),
    ACTIVITY_ACCURATE_CLUE(26, "活动精准线索推送"),
    ACCURATE_CLUE_TEMPLATE(27, "精准线索模版推送"),

    EVENING_GREETING_TEMPLATE_TEST(29,"晚安问候降级测试"),

    FISSION_SOMEONE_HELPED_ASSISTANCE(30, "裂变：有好友帮你助力"),
    FISSION_ASSISTANCE_HELP_OTHER(31, "裂变：帮好友助力"),
    FISSION_ASSISTANCE_SUCCESS(32, "裂变：助力完成，提醒领奖"),
    FISSION_AGENT_TAKE_ACTIVITY(33, "裂变：参与活动,通知代理人"),
    FISSION_TAKE_ACTIVITY(34, "裂变：参与活动"),
    FISSION_AGENT_COMPLETE_ACTIVITY(35, "裂变：有人完成,通知代理人"),
    FISSION_AGENT_MULTIPLE_MESSAGE(36, "裂变：代理人综合消息"),
    FISSION_USER_RECEIVE_MESSAGE(37, "裂变：用户收到代理人的私聊消息"),
    FISSION_SELLER_RECEIVE_MESSAGE(43, "裂变：代理人收到用户的私聊消息"),

    SINGLE_MESSAGE_USE(38, "自定义推送1"),
    EARLY_WARNING_REMIND_TEMPLATE(39,"预警提醒"),

    CUSTOM_MESSAGE_SEND(40,"自定义内容推送模版降级"),
    AFTERNOON_CONTENT_PUSH(41,"12点内容推送"),

    DAILY_TEMPLATE_TEST(42,"日报降级测试"),
    AFTERNOON_ACTIVITY_TEMPLATE_TEST(44,"午间动画推荐降级测试"),

    TEST_REPORT_TEMPLATE(45,"测算报告通知"),


    GAME_TEMPLATE_LOTTERY(50, "抽奖工具：参与抽奖聚合推送"),
    GAME_TEMPLATE_LOTTERY_CUSTOM(51, "抽奖工具：中销售员指定奖品"),
    GAME_TEMPLATE_RECEIVED_CUSTOM(52, "抽奖工具：领取销售员指定奖品"),
    GAME_TEMPLATE_RECEIVED_CUSTOM_TEMPLATE(53, "抽奖工具：领取销售员指定奖品降级模板"),
    EVENING_GREETING_CUSTOM_TEXT(54, "晚安心语客服文字消息"),

    TODAY_LUCK_CUSTOM_TEXT(55, "今日运势推送"),

    INTERACT_REMIND_TEMPLATE(56,"唤醒:模版推送"),

    /**
     * 自定义推送模版占用 60-70.具体模版名称在备注中。根据实际情况选择性，动态配置
     */
    CUSTOM_PUSH_TEMPLATE_2(60, "自定义推送2"),
    CUSTOM_PUSH_TEMPLATE_3(61, "自定义推送3"),
    CUSTOM_PUSH_TEMPLATE_4(62, "自定义推送4"),
    CUSTOM_PUSH_TEMPLATE_5(63, "自定义推送5"),
    CUSTOM_PUSH_TEMPLATE_10(70, "自定义推送10"),

    NEW_YEAR_ACTIVITY_PUSH_TEMPLATE(71, "元旦活动降级模版"),

    GREETING_CARD_RECEIVE(75, "节日贺卡：访客收下了贺卡"),
    GREETING_CARD_RECEIVE_DEMOTION(76, "节日贺卡：访客收下了贺卡降级模板"),
    GREETING_CARD_THANKS(77, "节日贺卡：访客答谢了贺卡"),
    GREETING_CARD_THANKS_DEMOTION(78, "节日贺卡：访客答谢了贺卡降级模板"),
    GREETING_CARD_MAKE_SUCCESS(79, "节日贺卡：制作完成"),
    GREETING_CARD_MAKE_SUCCESS_DEMOTION(80, "节日贺卡：制作完成降级模板"),

    GREETING_CARD_RECEIVE_TIMEOUT(86, "节日贺卡：访客领取红包超时"),
    GREETING_CARD_RECEIVE_TIMEOUT_TEMPLATE(87, "节日贺卡：访客领取红包超时降级模板"),
    GREETING_CARD_REFUND_SUCCESS(88, "节日贺卡：代理人红包退账成功"),
    GREETING_CARD_REFUND_SUCCESS_TEMPLATE(89, "节日贺卡：代理人红包退账成功降级模板"),
    GREETING_CARD_REFUND_FAIL(90, "节日贺卡：代理人红包退账失败"),
    GREETING_CARD_REFUND_FAIL_TEMPLATE(91, "节日贺卡：代理人红包退账失败降级模板"),
    GREETING_CARD_RECEIVE_SUCCESS(92, "节日贺卡：访客领取红包成功"),
    GREETING_CARD_RECEIVE_SUCCESS_DEMOTION(93, "节日贺卡：访客领取红包成功降级模板"),
    GREETING_CARD_CHARGE_SUCCESS(94, "节日贺卡：代理人充值成功"),
    GREETING_CARD_CHARGE_SUCCESS_DEMOTION(95, "节日贺卡：代理人充值成功降级模板"),
    GREETING_CARD_VISITOR_VIEW(96, "节日贺卡:付费增长访客预览"),
    GREETING_CARD_VISITOR_VIEW_TEMPLATE(97, "节日贺卡:付费增长访客预览降级模板"),
    GREETING_CARD_RECEIVE_THANKS(98, "节日贺卡：访客领取红包并答谢"),
    GREETING_CARD_RECEIVE_THANKS_DEMOTION(99, "节日贺卡：访客领取红包并答谢降级模板"),





    ;
    private Integer mark;
    private String desc;

    MessageMarkEnum(Integer mark, String desc) {
        this.mark = mark;
        this.desc = desc;
    }

    public Integer getMark() {
        return mark;
    }

    public String getDesc() {
        return desc;
    }

    public static MessageMarkEnum Of(Integer type) {
        for (MessageMarkEnum e :values())
            if (Objects.equals(type, e.getMark())) {
                return e;
            }
        throw new UnsupportedOperationException("不支持的消息");
    }

}
